<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Blog Gutener
 */

if( !function_exists( 'gutener_sidebar_body_class' ) ){
	/**
	* Add a class in body
	*
	* @since Blog Gutener 1.0.5
	* @param array $class
	* @return array $class
	*/
	function gutener_sidebar_body_class( $class ){
		
		// Adds a class of no-sidebar when there is no sidebar present.
		if ( get_theme_mod( 'sidebar_settings', 'no-sidebar' ) == 'right' ){
			if( gutener_wooCom_is_shop() ){
				if ( !is_active_sidebar( 'woocommerce-right-sidebar' ) ) {
					$class[] = 'no-sidebar';
				}
			}else{
				if ( !is_active_sidebar( 'right-sidebar' ) ) {
					$class[] = 'no-sidebar';
				}
			}
		}elseif ( get_theme_mod( 'sidebar_settings', 'no-sidebar' ) == 'left' ){
			if( gutener_wooCom_is_shop() ){
				if ( !is_active_sidebar( 'woocommerce-left-sidebar' ) ) {
					$class[] = 'no-sidebar';
				}
			}else{
				if ( !is_active_sidebar( 'left-sidebar' ) ) {
					$class[] = 'no-sidebar';
				}
			}
		}elseif ( get_theme_mod( 'sidebar_settings', 'no-sidebar' ) == 'right-left' ){
			if( gutener_wooCom_is_shop() ){
				if ( !is_active_sidebar( 'woocommerce-left-sidebar' ) && !is_active_sidebar( 'woocommerce-right-sidebar' ) ) {
					$class[] = 'no-sidebar';
				}
			}else{
				if ( !is_active_sidebar( 'left-sidebar' ) && !is_active_sidebar( 'right-sidebar' ) ) {
					$class[] = 'no-sidebar';
				}
			}
		}else{
			$class[] = 'content-no-sidebar';
		}

		return $class;
	}
	add_filter( 'body_class', 'gutener_sidebar_body_class' );
}

/**
 * Check if WooCommerce is activated and is shop page.
 *
 * @return bool
 * @since Blog Gutener 1.0.5
 */
if( !function_exists( 'gutener_wooCom_is_shop' ) ){
    function gutener_wooCom_is_shop() {
        if ( class_exists( 'woocommerce' ) ) {  
            if ( is_shop()  ) {
                return true;
            }
        }else{
            return false;
        }
    }
    add_action( 'wp', 'gutener_wooCom_is_shop' );
}

/**
 * Check if WooCommerce is activated and is cart page.
 *
 * @return bool
 * @since Blog Gutener 1.0.5
 */
if( !function_exists( 'gutener_wooCom_is_cart' ) ){
    function gutener_wooCom_is_cart() {
        if ( class_exists( 'woocommerce' ) ) {  
            if ( is_cart()  ) {
                return true;
            }
        }else{
            return false;
        }
    }
    add_action( 'wp', 'gutener_wooCom_is_cart' );
}

/**
 * Check if WooCommerce is activated and is checkout page.
 *
 * @return bool
 * @since Blog Gutener 1.0.5
 */
if( !function_exists( 'gutener_wooCom_is_checkout' ) ){
    function gutener_wooCom_is_checkout() {
        if ( class_exists( 'woocommerce' ) ) {  
            if ( is_checkout()  ) {
                return true;
            }
        }else{
            return false;
        }
    }
    add_action( 'wp', 'gutener_wooCom_is_checkout' );
}

/**
 * Check if WooCommerce is activated and is account page.
 *
 * @return bool
 * @since Blog Gutener 1.0.5
 */
if( !function_exists( 'gutener_wooCom_is_account_page' ) ){
    function gutener_wooCom_is_account_page() {
        if ( class_exists( 'woocommerce' ) ) {  
            if ( is_account_page()  ) {
                return true;
            }
        }else{
            return false;
        }
    }
    add_action( 'wp', 'gutener_wooCom_is_account_page' );
}

if ( ! function_exists( 'navxt_gutener_breadcrumb' ) ) :
	/**
	 * Adds NavXt Breadcrumb 
	 *
	 * @since Blog Gutener 1.0.5
	 * @param bool $transparent_nav True for Transparent Header. 
	 *
	 */
	
	function navxt_gutener_breadcrumb( $transparent_nav = false ) { ?>
		<div class="breadcrumb-wrap">
			<?php if( $transparent_nav ){ ?>
				<div class="container">
					<div class="breadcrumbs" typeof="BreadcrumbList" vocab="https://schema.org/">
						<?php bcn_display(); ?>
					</div>
				</div>
			<?php } else{ ?>
		        <div class="breadcrumbs" typeof="BreadcrumbList" vocab="https://schema.org/">
					<?php bcn_display(); ?>
				</div>
			<?php } ?>
		</div>
	<?php }
endif;

if( !function_exists( 'gutener_has_social' ) ){
	/**
	* Check if social media icon is empty.
	* 
	* @since Blog Gutener 1.0.5
	* @return bool
	*/
	function gutener_has_social(){
		$social_defaults = array(
			array(
				'icon' 		=> '',
				'link' 		=> '',
				'new_tab' 	=> true,
			)			
		);
		$social_icons = get_theme_mod( 'social_media_links', $social_defaults );
		$has_social = false;
		if ( is_array( $social_icons ) ){
			foreach( $social_icons as $value ){
				if( !empty( $value['icon'] ) ){
					$has_social = true;
					break;
				}
			}
		}
		return $has_social;
	}
}

if( !function_exists( 'gutener_social' ) ){
	/**
	* Add social icons.
	* 
	* @since Blog Gutener 1.0.5
	*/
	function gutener_social(){
		
	    echo '<ul class="social-group">';
		    $count = 0.2;
		    $social_defaults = array(
				array(
					'icon' 		=> '',
					'link' 		=> '',
					'new_tab' 	=> true,
				)			
			);
			$social_icons = get_theme_mod( 'social_media_links', $social_defaults );
		    foreach( $social_icons as $value ){
		        if( isset( $value['new_tab'] ) && $value['new_tab'] ){
		    		$link_target = '_blank';
		    	}else{
		    		$link_target = '';
		    	}
		        if( !empty( $value['icon'] ) ){
		            echo '<li><a href="' . esc_url( $value['link'] ) . '" target="' .esc_html( $link_target ). '"><i class=" ' . esc_attr( $value['icon'] ) . '"></i></a></li>';
		            $count = $count + 0.2;
		        }
		    }
	    echo '</ul>';
	}
}

/**
* Modify excerpt item priority to last in product detail page.
* @since Gutener 1.4.2
*/
remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20 );
add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 55 );

/**
 * Change column number of related products in product detail page.
 *
 * @return array
 * @since Gutener 1.4.2
 */
if( !function_exists( 'gutener_related_products_args' ) ){
    add_filter( 'woocommerce_output_related_products_args', 'gutener_related_products_args', 20 );
      function gutener_related_products_args( $args ) {
        $args[ 'columns'] = 3;
        return $args;
    }
}

/**
 * Check if WooCommerce is activated and is product detail page.
 *
 * @return bool
 * @since Gutener 1.4.2
 */
if( !function_exists( 'gutener_wooCom_is_product_page' ) ){
    function gutener_wooCom_is_product_page() {
        if ( class_exists( 'woocommerce' ) ) {  
            if ( is_product() ) {
                return true;
            }
        }else{
            return false;
        }
    }
    add_action( 'wp', 'gutener_wooCom_is_product_page' );
}

/**
 * Adds breadcrumb before product title in product detail page.
 *
 * @since Gutener 1.4.2
 */
if( !function_exists( 'gutener_product_detail_breadcrumb' ) ){
    add_action( 'woocommerce_single_product_summary', 'gutener_product_detail_breadcrumb', 1 );
    function gutener_product_detail_breadcrumb(){
        if( gutener_wooCom_is_product_page() ){
           if ( get_theme_mod( 'breadcrumbs_controls', 'disable_in_all_pages' ) == 'disable_in_all_pages' || get_theme_mod( 'breadcrumbs_controls', 'disable_in_all_pages' ) == 'show_in_all_page_post' ){
				if( function_exists( 'bcn_display' ) && !is_front_page() ){
					navxt_gutener_breadcrumb( false );
				}else{
					gutener_breadcrumb_wrap();
				}
			}
        }
    }
}

/**
 * Add left sidebar to product detail page.
 *
 * @since Gutener 1.4.2
 */
if( !function_exists( 'gutener_woo_product_detail_left_sidebar' ) ){
	function gutener_woo_product_detail_left_sidebar( $sidebarColumnClass ){
	    if( !get_theme_mod( 'disable_sidebar_woocommerce_page', false ) ){
	        if ( get_theme_mod( 'sidebar_settings', 'no-sidebar' ) == 'left' ){ 
	            if( is_active_sidebar( 'woocommerce-left-sidebar' ) ){ ?>
	                <div id="secondary" class="sidebar left-sidebar <?php echo esc_attr( $sidebarColumnClass ); ?>">
	                    <?php dynamic_sidebar( 'woocommerce-left-sidebar' ); ?>
	                </div>
	            <?php }
	            elseif( is_active_sidebar( 'left-sidebar' ) ){ ?>
	                <div id="secondary" class="sidebar left-sidebar <?php echo esc_attr( $sidebarColumnClass ); ?>">
	                    <?php dynamic_sidebar( 'left-sidebar' ); ?>
	                </div>
	            <?php }
	        }elseif ( get_theme_mod( 'sidebar_settings', 'no-sidebar' ) == 'right-left' ){
	            if( is_active_sidebar( 'woocommerce-left-sidebar' ) || is_active_sidebar( 'woocommerce-right-sidebar' ) ){ ?>
	                <div id="secondary" class="sidebar left-sidebar <?php echo esc_attr( $sidebarColumnClass ); ?>">
	                    <?php dynamic_sidebar( 'woocommerce-left-sidebar' ); ?>
	                </div>
	            <?php
	            }elseif( is_active_sidebar( 'left-sidebar' ) || is_active_sidebar( 'right-sidebar' ) ){ ?>
	                <div id="secondary" class="sidebar left-sidebar <?php echo esc_attr( $sidebarColumnClass ); ?>">
	                    <?php dynamic_sidebar( 'left-sidebar' ); ?>
	                </div>
	            <?php
	            }
	        }
	    }
	}
}

/**
 * Add right sidebar to product detail page.
 *
 * @since Gutener 1.4.2
 */
if( !function_exists( 'gutener_woo_product_detail_right_sidebar' ) ){
	function gutener_woo_product_detail_right_sidebar( $sidebarColumnClass ){
	    if( !get_theme_mod( 'disable_sidebar_woocommerce_page', false ) ){
	        if ( get_theme_mod( 'sidebar_settings', 'no-sidebar' ) == 'right' ){ 
	            if( is_active_sidebar( 'woocommerce-right-sidebar') ){ ?>
	                <div id="secondary" class="sidebar right-sidebar <?php echo esc_attr( $sidebarColumnClass ); ?>">
	                    <?php dynamic_sidebar( 'woocommerce-right-sidebar' ); ?>
	                </div>
	            <?php }
	            elseif( is_active_sidebar( 'right-sidebar' ) ){ ?>
	                <div id="secondary" class="sidebar right-sidebar <?php echo esc_attr( $sidebarColumnClass ); ?>">
	                    <?php dynamic_sidebar( 'right-sidebar' ); ?>
	                </div>
	            <?php }
	        }elseif ( get_theme_mod( 'sidebar_settings', 'no-sidebar' ) == 'right-left' ){
	            if( is_active_sidebar( 'woocommerce-left-sidebar' ) || is_active_sidebar( 'woocommerce-right-sidebar' ) ){ ?>
	                <div id="secondary-sidebar" class="sidebar right-sidebar <?php echo esc_attr( $sidebarColumnClass ); ?>">
	                    <?php dynamic_sidebar( 'woocommerce-right-sidebar' ); ?>
	                </div>
	            <?php
	            }elseif( is_active_sidebar( 'left-sidebar' ) || is_active_sidebar( 'right-sidebar' ) ){ ?>
	                <div id="secondary-sidebar" class="sidebar right-sidebar <?php echo esc_attr( $sidebarColumnClass ); ?>">
	                    <?php dynamic_sidebar( 'right-sidebar' ); ?>
	                </div>
	            <?php
	            }
	        }
	    }
	}
}

/**
 * Returns the sidebar column classes in product detail page.
 *
 * @return array
 * @since Gutener 1.4.2
 */
if( !function_exists( 'gutener_get_sidebar_class' ) ){
    function gutener_get_sidebar_class(){
        $sidebarClass = 'col-lg-8';
        $sidebarColumnClass = 'col-lg-4';

        if ( get_theme_mod( 'sidebar_settings', 'no-sidebar' ) == 'right' ){
            if( !is_active_sidebar( 'woocommerce-right-sidebar' ) && !is_active_sidebar( 'right-sidebar') ){
                $sidebarClass = "col-12";
            }   
        }elseif ( get_theme_mod( 'sidebar_settings', 'no-sidebar' ) == 'left' ){
            if( !is_active_sidebar( 'woocommerce-left-sidebar' ) && !is_active_sidebar( 'left-sidebar') ){
                $sidebarClass = "col-12";
            }   
        }elseif ( get_theme_mod( 'sidebar_settings', 'no-sidebar' ) == 'right-left' ){
            $sidebarClass = 'col-lg-6';
            $sidebarColumnClass = 'col-lg-3';
            if( !is_active_sidebar( 'woocommerce-left-sidebar' ) && !is_active_sidebar( 'left-sidebar' ) && !is_active_sidebar( 'woocommerce-right-sidebar' ) && !is_active_sidebar( 'right-sidebarleft-sidebar' ) ){
                $sidebarClass = "col-12";
            }
        }
        if ( get_theme_mod( 'sidebar_settings', 'no-sidebar' ) == 'no-sidebar' || get_theme_mod( 'disable_sidebar_woocommerce_page', false ) ){
            $sidebarClass = 'col-12';
        }
        $colClasses = array(
            'sidebarClass' => $sidebarClass, 
            'sidebarColumnClass' => $sidebarColumnClass, 
        );
        return $colClasses;
    }
}

/**
 * Add wrapper product gallery in product detail page.
 *
 * @since Gutener 1.4.2
 */
if( !function_exists( 'gutener_woocommerce_before_single_product_summary' ) ){
	add_action( 'woocommerce_before_single_product_summary', 'gutener_woocommerce_before_single_product_summary', 5 );
	function gutener_woocommerce_before_single_product_summary(){
	    echo '<div class="product-detail-wrapper">';
	}
}

/**
 * Add left sidebar before tabs in product detail page.
 *
 * @since Gutener 1.4.2
 */
if( !function_exists( 'gutener_woocommerce_after_single_product_summary' ) ){
	add_action( 'woocommerce_after_single_product_summary', 'gutener_woocommerce_after_single_product_summary', 5 );
	function gutener_woocommerce_after_single_product_summary(){
	    $getSidebarClass = gutener_get_sidebar_class();
	    echo '</div>';/* .product-detail-wrapper */
	    echo '<div class="row">';
	        gutener_woo_product_detail_left_sidebar( $getSidebarClass[ 'sidebarColumnClass' ] );
	        echo '<div class="'. $getSidebarClass[ 'sidebarClass' ] .'">';
	}
}

/**
 * Add right sidebar before tabs in product detail page.
 *
 * @since Gutener 1.4.2
 */
if( !function_exists( 'gutener_woocommerce_after_single_product' ) ){
	add_action( 'woocommerce_after_single_product', 'gutener_woocommerce_after_single_product' );
	function gutener_woocommerce_after_single_product(){
	    $getSidebarClass = gutener_get_sidebar_class();
	    gutener_woo_product_detail_right_sidebar( $getSidebarClass[ 'sidebarColumnClass' ] );
	        echo '</div>';/* col woocommerce tabs and related products */
	    echo '</div>';/* .row */
	}
}